function hs=mHinkJ(ts,s,j)
% mHinkJ	- Finds enthalpies for compounds, allows multiple temperatures
%  
% Matrix version of HinkJ.  The temperatures may be a vector.
% Other arguments are the same.
%
% function hs=mHinkJ(ts,s,j)
% Arguments:
%      s     the physical state: 'v' for vapor, 'l' for liquid
%              or 's' for solid.
%      j     the indices of the compounds in cnms that are
%            to be included.  If the third argument is omitted,
%            all compounds are included.
%      hs    returns the enthalpies for each temperature in a row and
%            each compound in a column.
%
% Example: For cnms set with setnme and only water in it:
%     >> mHinkJ([200 300],'v')
%     will give the enthalpy of vapor water at 200K and 300K
%     as a column vector.
% 
% help revised by MAH
hs=[];
for k=1:length(ts)
    if nargin<=2
       hs=[hs;HinkJ(ts(k),s)]; 
    else  
       hs=[hs;HinkJ(ts(k),s,j)];
    end
end
